# Tutorials

1. **Sampling a posterior**: Review available choices for events, approximants, priors and samplers. Optionally marginalize over distance.

1. **Event data**: How to download files from GWOSC and make your own `EventData` object (illustrated on GW170817).

1.  **Make your own prior** Define a prior and a coordinate system of your own.

1. **Factorized QAS** How to run [factorized parameter estimation](https://arxiv.org/abs/2210.16278) (i.e., marginalizing over extrinsic parameters) with quadrupolar, aligned-spin waveform models.

1. **Factorized PHM** Analogous for precessing, higher modes waveform models.

1. **Extrinsic marginalization** *New!* Shows details of the extrinsic marginalization.
